==> ui-18.1.2.tgz: package/components/time-picker/TimePicker.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { isUndefined } from 'lodash';
import React, { useRef } from 'react';
import { ClockCircleOutlined } from '@react-devui/icons';
import { getClassName } from '@react-devui/utils';
import { useGeneralContext } from '../../hooks';
import { registerComponentMate } from '../../utils';
import { DDateInput } from '../_date-input';
import { getCols, orderTime } from '../_date-input/utils';
import { DButton } from '../button';
import { useComponentConfig, usePrefixConfig, useTranslation } from '../root';
import { DPanel } from './Panel';
const { COMPONENT_NAME } = registerComponentMate({ COMPONENT_NAME: 'DTimePicker' });
function TimePicker(props, ref) {
    var _a;
    const _b = useComponentConfig(COMPONENT_NAME, props), { dRef, dFormControl, dModel, dFormat, dVisible, dPlacement = 'bottom-left', dOrder = 'ascend', dPlaceholder, dRange = false, dSize, dClearable = false, dDisabled = false, dConfigTime, d12Hour = false, dPopupClassName, dInputRender, onModelChange, onVisibleChange, afterVisibleChange, onClear } = _b, restProps = __rest(_b, ["dRef", "dFormControl", "dModel", "dFormat", "dVisible", "dPlacement", "dOrder", "dPlaceholder", "dRange", "dSize", "dClearable", "dDisabled", "dConfigTime", "d12Hour", "dPopupClassName", "dInputRender", "onModelChange", "onVisibleChange", "afterVisibleChange", "onClear"]);
    //#region Context
    const dPrefix = usePrefixConfig();
    const { gSize, gDisabled } = useGeneralContext();
    //#endregion
    //#region Ref
    const updatePanelRef = useRef(null);
    //#endregion
    const [t] = useTranslation();
    const size = dSize !== null && dSize !== void 0 ? dSize : gSize;
    const disabled = (_a = (dDisabled || gDisabled || (dFormControl === null || dFormControl === void 0 ? void 0 : dFormControl.control.disabled))) !== null && _a !== void 0 ? _a : false;
    const format = isUndefined(dFormat) ? (d12Hour ? 'hh:mm:ss A' : 'HH:mm:ss') : dFormat;
    const [placeholderLeft = t('TimePicker', dRange ? 'Start time' : 'Select time'), placeholderRight = t('TimePicker', 'End time')] = (dRange ? dPlaceholder !== null && dPlaceholder !== void 0 ? dPlaceholder : [] : [dPlaceholder]);
    return (_jsx(DDateInput, Object.assign({}, restProps, { ref: ref, dRef: dRef, dClassNamePrefix: "time-picker", dFormControl: dFormControl, dModel: dModel, dFormat: format, dVisible: dVisible, dPlacement: dPlacement, dOrder: (date) => orderTime(date, dOrder), dPlaceholder: [placeholderLeft, placeholderRight], dSuffix: _jsx(ClockCircleOutlined, {}), dRange: dRange, dSize: size, dClearable: dClearable, dDisabled: disabled, dInputRender: dInputRender, onModelChange: onModelChange, onVisibleChange: onVisibleChange, onUpdatePanel: (date) => {
            var _a;
            (_a = updatePanelRef.current) === null || _a === void 0 ? void 0 : _a.call(updatePanelRef, date);
        }, afterVisibleChange: afterVisibleChange, onClear: onClear }, { children: ({ date, isFocus, changeDate, renderPopup }) => renderPopup(_jsxs("div", Object.assign({ className: getClassName(dPopupClassName, `${dPrefix}time-picker__popup`) }, { children: [_jsx(DPanel, { ref: updatePanelRef, dTime: date[isFocus[0] ? 0 : 1], dCols: getCols(format), d12Hour: d12Hour, dConfigTime: dConfigTime ? (...args) => dConfigTime(...args, isFocus[0] ? 'start' : 'end', date) : undefined, onTimeChange: changeDate }), _jsx("div", Object.assign({ className: `${dPrefix}time-picker__footer` }, { children: _jsx(DButton, Object.assign({ onClick: () => {
                            var _a;
                            const now = new Date();
                            changeDate(now);
                            (_a = updatePanelRef.current) === null || _a === void 0 ? void 0 : _a.call(updatePanelRef, now);
                        }, dType: "link" }, { children: t('TimePicker', 'Now') })) }))] }))) })));
}
export const DTimePicker = React.forwardRef(TimePicker);

==> ui-18.3.2.tgz: package/components/time-picker/TimePicker.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { isUndefined } from 'lodash';
import React, { useRef } from 'react';
import { ClockCircleOutlined } from '@react-devui/icons';
import { getClassName } from '@react-devui/utils';
import { useDValue, useGeneralContext } from '../../hooks';
import { registerComponentMate } from '../../utils';
import { DDateInput } from '../_date-input';
import { getCols, orderTime } from '../_date-input/utils';
import { DButton } from '../button';
import { useComponentConfig, usePrefixConfig, useTranslation } from '../root';
import { DPanel } from './Panel';
const { COMPONENT_NAME } = registerComponentMate({ COMPONENT_NAME: 'DTimePicker' });
function TimePicker(props, ref) {
    var _a;
    const _b = useComponentConfig(COMPONENT_NAME, props), { dRef, dFormControl, dModel, dFormat, dVisible, dPlacement = 'bottom-left', dOrder = 'ascend', dPlaceholder, dRange = false, dSize, dClearable = false, dDisabled = false, dConfigTime, d12Hour = false, dPopupClassName, dInputRender, onModelChange, onVisibleChange, afterVisibleChange, onClear } = _b, restProps = __rest(_b, ["dRef", "dFormControl", "dModel", "dFormat", "dVisible", "dPlacement", "dOrder", "dPlaceholder", "dRange", "dSize", "dClearable", "dDisabled", "dConfigTime", "d12Hour", "dPopupClassName", "dInputRender", "onModelChange", "onVisibleChange", "afterVisibleChange", "onClear"]);
    //#region Context
    const dPrefix = usePrefixConfig();
    const { gSize, gDisabled } = useGeneralContext();
    //#endregion
    //#region Ref
    const updatePanelRef = useRef(null);
    //#endregion
    const [t] = useTranslation();
    const [visible, changeVisible] = useDValue(false, dVisible, onVisibleChange);
    const size = dSize !== null && dSize !== void 0 ? dSize : gSize;
    const disabled = (_a = (dDisabled || gDisabled || (dFormControl === null || dFormControl === void 0 ? void 0 : dFormControl.control.disabled))) !== null && _a !== void 0 ? _a : false;
    const format = isUndefined(dFormat) ? (d12Hour ? 'hh:mm:ss A' : 'HH:mm:ss') : dFormat;
    const [placeholderLeft = t('TimePicker', dRange ? 'Start time' : 'Select time'), placeholderRight = t('TimePicker', 'End time')] = (dRange ? dPlaceholder !== null && dPlaceholder !== void 0 ? dPlaceholder : [] : [dPlaceholder]);
    return (_jsx(DDateInput, Object.assign({}, restProps, { ref: ref, dRef: dRef, dClassNamePrefix: "time-picker", dFormControl: dFormControl, dModel: dModel, dFormat: format, dVisible: visible, dPlacement: dPlacement, dOrder: (date) => orderTime(date, dOrder), dPlaceholder: [placeholderLeft, placeholderRight], dSuffix: _jsx(ClockCircleOutlined, {}), dRange: dRange, dSize: size, dClearable: dClearable, dDisabled: disabled, dInputRender: dInputRender, onModelChange: onModelChange, onVisibleChange: changeVisible, onUpdatePanel: (date) => {
            var _a;
            (_a = updatePanelRef.current) === null || _a === void 0 ? void 0 : _a.call(updatePanelRef, date);
        }, afterVisibleChange: afterVisibleChange, onClear: onClear }, { children: ({ date, isFocus, changeDate, renderPopup }) => renderPopup(_jsxs("div", Object.assign({ className: getClassName(dPopupClassName, `${dPrefix}time-picker__popup`) }, { children: [_jsx(DPanel, { ref: updatePanelRef, dTime: date[isFocus[0] ? 0 : 1], dCols: getCols(format), d12Hour: d12Hour, dConfigTime: dConfigTime ? (...args) => dConfigTime(...args, isFocus[0] ? 'start' : 'end', date) : undefined, onTimeChange: changeDate }), _jsx("div", Object.assign({ className: `${dPrefix}time-picker__footer` }, { children: _jsx(DButton, Object.assign({ onClick: () => {
                            var _a;
                            const now = new Date();
                            changeDate(now);
                            (_a = updatePanelRef.current) === null || _a === void 0 ? void 0 : _a.call(updatePanelRef, now);
                            changeVisible(false);
                        }, dType: "link" }, { children: t('TimePicker', 'Now') })) }))] }))) })));
}
export const DTimePicker = React.forwardRef(TimePicker);
